@@ -1,7 +1,7 @@
 import os
 import sys
 from pathlib import Path
-from typing import BinaryIO
+from typing import BinaryIO, TYPE_CHECKING
 
 
 is_darwin = sys.platform == "darwin"
@@ -10,7 +10,13 @@ is_win32 = os.name == "nt"
 stdout: BinaryIO = sys.stdout.buffer
 
 
-class DeprecatedPath(type(Path())):
+if TYPE_CHECKING:  # pragma: no cover
+    _BasePath = Path
+else:
+    _BasePath = type(Path())
+
+
+class DeprecatedPath(_BasePath):
     pass
 
 
